package Org::To::Text;

use 5.010;
use Log::Any '$log';

use vars qw($VERSION);

our $VERSION = '0.00'; # VERSION

1;
# ABSTRACT: Export Org document to text


__END__
=pod

=head1 NAME

Org::To::Text - Export Org document to text

=head1 VERSION

version 0.00

=head1 SYNOPSIS

 use Org::To::Text qw(org_to_text);
 my $text = org_to_text(source=>$org);

=head1 DESCRIPTION

NOT YET IMPLEMENTED.

=head1 SEE ALSO

L<Org::Parser>

L<Org::To::HTML>

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

